import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 * Testovací třída VigenerovaSifraTest slouží k otestování
 * třídy VigenerovaSifra.
 *
 * @author    Luboš Pavlíček
 * @version   1.00.000,  19.2.2014
 */
public class VigenerovaSifraTest
{

    //== KONSTRUKTORY A TOVÁRNÍ METODY =============================================
    //-- Testovací třída vystačí s prázdným implicitním konstruktorem ----------

    //== VLASTNÍ TESTY =============================================================

    @Test
    public void testHesloWhite() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("WHITE");
        assertEquals("Z", vigenerova.zasifruj("d"));
        assertEquals("D", vigenerova.desifruj("Z"));

        assertEquals("ZP", vigenerova.zasifruj("DI"));
        assertEquals("DI", vigenerova.desifruj("ZP"));

        assertEquals("ZPDXVP", vigenerova.zasifruj("DIVERT"));
        assertEquals("DIVERT", vigenerova.desifruj("ZPDXVP"));
        
        assertEquals("ZPDXVPAZHSLZBHIWZBKMZNM", vigenerova.zasifruj("diverttroopstoeastridge"));
        assertEquals("DIVERTTROOPSTOEASTRIDGE", vigenerova.desifruj("ZPDXVPAZHSLZBHIWZBKMZNM"));

    }
    
    @Test
    public void testHesloWhiteNormalizace() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("WHITE");
        
        assertEquals("YLAMMJH", vigenerova.zasifruj("čeština"));
        assertEquals("CESTINA", vigenerova.desifruj("YLAMMJH"));
        
        assertEquals("YLAMMJH", vigenerova.zasifruj("če ština"));
        assertEquals("CESTINA", vigenerova.desifruj("YLAMMJH"));

        assertEquals("YLAMMJH", vigenerova.zasifruj("8če ština$"));
        assertEquals("CESTINA", vigenerova.desifruj("YLAMMJH"));
    }

    @Test
    public void testHesloBagr() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        assertEquals("X", vigenerova.zasifruj("w"));
        assertEquals("W", vigenerova.desifruj("X"));

        assertEquals("XIQZQEJZF", vigenerova.zasifruj("wikipedie"));
        assertEquals("WIKIPEDIE", vigenerova.desifruj("XIQZQEJZF"));

    }
    
    @Test
    public void testHesloBagr2() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr2");
        assertEquals("X", vigenerova.zasifruj("w"));
        assertEquals("W", vigenerova.desifruj("X"));

        assertEquals("XIQZQEJZF", vigenerova.zasifruj("wikipedie"));
        assertEquals("WIKIPEDIE", vigenerova.desifruj("XIQZQEJZF"));

    }
    
    @Test
    public void testHesloBagr3() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("Bagř");
        assertEquals("X", vigenerova.zasifruj("w"));
        assertEquals("W", vigenerova.desifruj("X"));

        assertEquals("XIQZQEJZF", vigenerova.zasifruj("wikipedie"));
        assertEquals("WIKIPEDIE", vigenerova.desifruj("XIQZQEJZF"));

    }

    @Test(expected=IllegalArgumentException.class)
    public void testHesloException_1() {
        VigenerovaSifra vigenerova = new VigenerovaSifra(null);
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testHesloException_2() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("");
    }

    @Test(expected=IllegalArgumentException.class)
    public void testHesloException_3() {
        VigenerovaSifra vigenerova = new VigenerovaSifra(" 37");
    }

    @Test(expected=IllegalArgumentException.class)
    public void testZasifrujException_1() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.zasifruj(null);
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testZasifrujException_2() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.zasifruj("");
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testZasifrujException_3() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.zasifruj(" 77+");
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testDesifrujException_1() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.desifruj(null);
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testDesifrujException_2() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.desifruj("");
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testDesifrujException_3() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.desifruj("bagr");
    }
    
    @Test(expected=IllegalArgumentException.class)
    public void testDesifrujException_4() {
        VigenerovaSifra vigenerova = new VigenerovaSifra("bagr");
        vigenerova.desifruj("BAGR4");
    }
    
}